@@ -462,7 +462,7 @@ int TabBar::drawTab(int x, int y, int index, QPainter &painter)
     painter.setFont(font);
 
     QFontMetrics fontMetrics(font);
-    textWidth = fontMetrics.width(title) + 10;
+    textWidth = fontMetrics.horizontalAdvance(title) + 10;
 
     // Draw the Prevent Closing image in the tab button.
     if (m_mainWindow->sessionStack()->isSessionClosable(sessionId) == false) {
@@ -549,9 +549,9 @@ void TabBar::mousePressEvent(QMouseEvent *event)
     if (index == -1)
         return;
 
-    if (event->button() == Qt::LeftButton || event->button() == Qt::MidButton) {
+    if (event->button() == Qt::LeftButton || event->button() == Qt::MiddleButton) {
         m_startPos = event->pos();
-        if (index != m_tabs.indexOf(m_selectedSessionId) || event->button() == Qt::MidButton) {
+        if (index != m_tabs.indexOf(m_selectedSessionId) || event->button() == Qt::MiddleButton) {
             m_mousePressed = true;
             m_mousePressedIndex = index;
         }
@@ -575,7 +575,7 @@ void TabBar::mouseReleaseEvent(QMouseEvent *event)
         if (event->button() == Qt::LeftButton && index != m_tabs.indexOf(m_selectedSessionId))
             Q_EMIT tabSelected(m_tabs.at(index));
 
-        if (event->button() == Qt::MidButton)
+        if (event->button() == Qt::MiddleButton)
             Q_EMIT tabClosed(m_tabs.at(index));
     }
 
@@ -589,7 +589,7 @@ void TabBar::mouseReleaseEvent(QMouseEvent *event)
 
 void TabBar::mouseMoveEvent(QMouseEvent *event)
 {
-    if (!m_startPos.isNull() && ((event->buttons() & Qt::LeftButton) || (event->buttons() & Qt::MidButton))) {
+    if (!m_startPos.isNull() && ((event->buttons() & Qt::LeftButton) || (event->buttons() & Qt::MiddleButton))) {
         int distance = (event->pos() - m_startPos).manhattanLength();
 
         if (distance >= QApplication::startDragDistance()) {
@@ -826,7 +826,7 @@ void TabBar::moveTabLeft(int sessionId)
     if (index < 1)
         return;
 
-    m_tabs.swap(index, index - 1);
+    m_tabs.swapItemsAt(index, index - 1);
 
     repaint();
 
@@ -843,7 +843,7 @@ void TabBar::moveTabRight(int sessionId)
     if (index == -1 || index == m_tabs.count() - 1)
         return;
 
-    m_tabs.swap(index, index + 1);
+    m_tabs.swapItemsAt(index, index + 1);
 
     repaint();
 
@@ -944,7 +944,6 @@ void TabBar::startDrag(int index)
 
     int x = index ? m_tabWidths.at(index - 1) : m_skin->tabBarPosition().x();
     int tabWidth = m_tabWidths.at(index) - x;
-    QString title = tabTitle(sessionId);
 
     QPixmap tab(tabWidth, height());
     QColor fillColor(Settings::backgroundColor());
@@ -955,7 +954,7 @@ void TabBar::startDrag(int index)
     tab.fill(fillColor);
 
     QPainter painter(&tab);
-    painter.initFrom(this);
+    painter.begin(this);
     painter.setPen(m_skin->tabBarTextColor());
 
     drawTab(0, 0, index, painter);
